@@ -120,9 +120,6 @@ Thennarasu <- function(.data, env, gen, resp, verbose = TRUE) {
 #' print(model)
 #' }
 print.Thennarasu <- function(x, export = FALSE, file.name = NULL, digits = 3, ...) {
-  if (!class(x) == "Thennarasu") {
-    stop("The object must be of class 'Thennarasu'")
-  }
   if (export == TRUE) {
     file.name <- ifelse(is.null(file.name) == TRUE, "Thennarasu summary", file.name)
     sink(paste0(file.name, ".txt"))
