@@ -169,13 +169,15 @@ mps <- function(.data,
                 block = NULL,
                 by = NULL,
                 random = "gen",
-                performance = "blupg",
+                performance = c("blupg", "blueg"),
                 stability = "waasb",
                 ideotype_mper = NULL,
                 ideotype_stab = NULL,
                 wmper = NULL,
                 verbose = TRUE) {
 
+  performance <- rlang::arg_match(performance)
+
   if (!missing(by)){
     if(length(as.list(substitute(by))[-1L]) != 0){
       stop("Only one grouping variable can be used in the argument 'by'.\nUse 'group_by()' to pass '.data' grouped by more than one variable.", call. = FALSE)
@@ -249,8 +251,9 @@ mps <- function(.data,
                 verbose = verbose)
   }
   # mean performance
-  observed <- gmd(mod, "data", verbose = FALSE) %>%
-    means_by(GEN) %>%
+  observed <-
+    gmd(mod, "data", verbose = FALSE) %>%
+    mean_by(GEN) %>%
     column_to_rownames("GEN")
   mperf <-
     switch(performance,
