@@ -199,7 +199,7 @@ mtmps <- function(model,
                         Xo = colMeans(means.factor),
                         Xs = colMeans(means.factor[names(MTSI)[1:ngs], ]),
                         SD = Xs - Xo,
-                        SDperc = (Xs - Xo) / Xo * 100)
+                        SDperc = (Xs - Xo) / abs(Xo) * 100)
       stat_dif_mps <-
         desc_stat(sel_dif, SDperc, stats = c("min, mean, ci.t, sd.amo, max, sum"))
       sel_dif_mean <-
@@ -208,7 +208,7 @@ mtmps <- function(model,
                Xo = colMeans(observed),
                Xs = colMeans(observed[names(MTSI)[1:ngs], ]),
                SD = Xs - colMeans(observed),
-               SDperc = (Xs - colMeans(observed)) / colMeans(observed) * 100) %>%
+               SDperc = (Xs - colMeans(observed)) / abs(colMeans(observed)) * 100) %>%
         left_join(df_ideotype, by = "VAR") %>%
         mutate(sense = case_when(sense == "l" ~ "decrease",
                                  sense == "a" ~ "average",
@@ -237,7 +237,7 @@ mtmps <- function(model,
           Xo = colMeans(waasb_index %>% select_numeric_cols()),
           Xs = waasb_selected,
           SD = Xs - Xo,
-          SDperc = (Xs - Xo) / Xo * 100) %>%
+          SDperc = (Xs - Xo) / abs(Xo) * 100) %>%
         left_join(df_ideotype_stab, by = "VAR") %>%
         mutate(sense = case_when(sense == "l" ~ "decrease",
                                  sense == "a" ~ "average",
